@@ -124,7 +124,7 @@ BOOST_AUTO_TEST_CASE(t1)
 
 	BOOST_TEST(rmsd < 1e-5);
 
-	// std::cout << "rmsd: " << RMSd(p1, p2) << std::endl;
+	// std::cout << "rmsd: " << RMSd(p1, p2) << '\n';
 }
 
 BOOST_AUTO_TEST_CASE(t2)
@@ -161,7 +161,7 @@ BOOST_AUTO_TEST_CASE(t3)
 	v.rotate(q);
 	v += p[0];
 
-	std::cout << v << std::endl;
+	std::cout << v << '\n';
 
 	double a = cif::angle(v, p[0], p[1]);
 
@@ -517,6 +517,55 @@ BOOST_AUTO_TEST_CASE(symm_2bi3_1, *utf::tolerance(0.1f))
 	}
 }
 
+BOOST_AUTO_TEST_CASE(symm_2bi3_1a, *utf::tolerance(0.1f))
+{
+	using namespace cif::literals;
+
+	cif::file f(gTestDir / "2bi3.cif.gz");
+
+	auto &db = f.front();
+
+	cif::crystal c(db);
+	auto struct_conn = db["struct_conn"];
+	auto atom_site = db["atom_site"];
+
+	for (const auto &[
+			asym1, seqid1, authseqid1, atomid1, symm1,
+			asym2, seqid2, authseqid2, atomid2, symm2,
+			dist] : struct_conn.find<
+				std::string,std::optional<int>,std::string,std::string,std::string,
+				std::string,std::optional<int>,std::string,std::string,std::string,
+				float>(
+			cif::key("ptnr1_symmetry") != "1_555" or cif::key("ptnr2_symmetry") != "1_555",
+			"ptnr1_label_asym_id", "ptnr1_label_seq_id", "ptnr1_auth_seq_id", "ptnr1_label_atom_id", "ptnr1_symmetry", 
+			"ptnr2_label_asym_id", "ptnr2_label_seq_id", "ptnr2_auth_seq_id", "ptnr2_label_atom_id", "ptnr2_symmetry", 
+			"pdbx_dist_value"
+		))
+	{
+		cif::point p1 = atom_site.find1<float,float,float>(
+			"label_asym_id"_key == asym1 and "label_seq_id"_key == seqid1 and "auth_seq_id"_key == authseqid1 and "label_atom_id"_key == atomid1,
+			"cartn_x", "cartn_y", "cartn_z");
+		cif::point p2 = atom_site.find1<float,float,float>(
+			"label_asym_id"_key == asym2 and "label_seq_id"_key == seqid2 and "auth_seq_id"_key == authseqid2 and "label_atom_id"_key == atomid2,
+			"cartn_x", "cartn_y", "cartn_z");
+
+		auto sa1 = c.symmetry_copy(p1, cif::sym_op(symm1));
+		auto sa2 = c.symmetry_copy(p2, cif::sym_op(symm2));
+
+		BOOST_TEST(cif::distance(sa1, sa2) == dist);
+
+		const auto &[d, p, so] = c.closest_symmetry_copy(p1, p2);
+
+		BOOST_TEST(p.m_x == sa2.m_x);
+		BOOST_TEST(p.m_y == sa2.m_y);
+		BOOST_TEST(p.m_z == sa2.m_z);
+
+		BOOST_TEST(d == dist);
+		BOOST_TEST(so.string() == symm2);
+	}
+}
+
+
 
 BOOST_AUTO_TEST_CASE(symm_3bwh_1, *utf::tolerance(0.1f))
 {
